==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/nb/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"field-second-relative+0": "nå",
	"field-weekday": "Ukedag",
	"field-wed-relative+0": "onsdag denne uken",
	"field-wed-relative+1": "onsdag neste uke",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-tue-relative+-1": "tirsdag sist uke",
	"days-format-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"dateFormat-long": "d. MMMM y G",
	"field-fri-relative+-1": "fredag sist uke",
	"field-wed-relative+-1": "onsdag sist uke",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dayPeriods-format-wide-pm": "p.m.",
	"dateFormat-full": "EEEE d. MMMM y G",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"field-thu-relative+-1": "torsdag sist uke",
	"dateFormatItem-Md": "d.M.",
	"dayPeriods-format-abbr-am": "a.m.",
	"field-era": "Tidsalder",
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "År",
	"field-hour": "Time",
	"field-sat-relative+0": "lørdag denne uken",
	"field-sat-relative+1": "lørdag neste uke",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "i dag",
	"field-thu-relative+0": "torsdag denne uken",
	"field-day-relative+1": "i morgen",
	"field-thu-relative+1": "torsdag neste uke",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "i overmorgen",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"dateFormatItem-M": "L.",
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "søndag denne uken",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "søndag neste uke",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"AM"
	],
	"field-minute": "Minutt",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E d.M",
	"field-fri-relative+0": "fredag denne uken",
	"field-fri-relative+1": "fredag neste uke",
	"field-day": "Dag",
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"field-zone": "Tidssone",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "I fjor",
	"field-month-relative+-1": "Sist måned",
	"dateFormatItem-hm": "h.mm a",
	"dayPeriods-format-abbr-pm": "p.m.",
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-month": "Måned",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-tue-relative+0": "tirsdag denne uken",
	"field-tue-relative+1": "tirsdag neste uke",
	"dayPeriods-format-wide-am": "a.m.",
	"field-mon-relative+0": "mandag denne uken",
	"field-mon-relative+1": "mandag neste uke",
	"dateFormat-short": "d.M. y G",
	"field-second": "Sekund",
	"field-sat-relative+-1": "lørdag sist uke",
	"field-sun-relative+-1": "søndag sist uke",
	"field-month-relative+0": "Denne måneden",
	"field-month-relative+1": "Neste måned",
	"dateFormatItem-Ed": "E d.",
	"field-week": "Uke",
	"dateFormat-medium": "d. MMM y G",
	"field-year-relative+0": "Dette året",
	"field-week-relative+-1": "Sist uke",
	"dateFormatItem-yyyyM": "M.y G",
	"field-year-relative+1": "Neste år",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "mandag sist uke",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "Denne uken",
	"field-week-relative+1": "Neste uke"
}
//end v1.x content
);

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojo/cldr/nls/nb/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"field-second-relative+0": "nå",
	"field-weekday": "Ukedag",
	"field-wed-relative+0": "onsdag denne uken",
	"field-wed-relative+1": "onsdag neste uke",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-tue-relative+-1": "tirsdag sist uke",
	"days-format-short": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"dateFormat-long": "d. MMMM y G",
	"field-fri-relative+-1": "fredag sist uke",
	"field-wed-relative+-1": "onsdag sist uke",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dayPeriods-format-wide-pm": "p.m.",
	"dateFormat-full": "EEEE d. MMMM y G",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"field-thu-relative+-1": "torsdag sist uke",
	"dateFormatItem-Md": "d.M.",
	"dayPeriods-format-abbr-am": "a.m.",
	"field-era": "Tidsalder",
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "År",
	"field-hour": "Time",
	"field-sat-relative+0": "lørdag denne uken",
	"field-sat-relative+1": "lørdag neste uke",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "i dag",
	"field-thu-relative+0": "torsdag denne uken",
	"field-day-relative+1": "i morgen",
	"field-thu-relative+1": "torsdag neste uke",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "i overmorgen",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"dateFormatItem-M": "L.",
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "søndag denne uken",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "søndag neste uke",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"AM"
	],
	"field-minute": "Minutt",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"sø.",
		"ma.",
		"ti.",
		"on.",
		"to.",
		"fr.",
		"lø."
	],
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E d.M",
	"field-fri-relative+0": "fredag denne uken",
	"field-fri-relative+1": "fredag neste uke",
	"field-day": "Dag",
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"field-zone": "Tidssone",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "i fjor",
	"field-month-relative+-1": "forrige måned",
	"dateFormatItem-hm": "h.mm a",
	"dayPeriods-format-abbr-pm": "p.m.",
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-month": "Måned",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-tue-relative+0": "tirsdag denne uken",
	"field-tue-relative+1": "tirsdag neste uke",
	"dayPeriods-format-wide-am": "a.m.",
	"field-mon-relative+0": "mandag denne uken",
	"field-mon-relative+1": "mandag neste uke",
	"dateFormat-short": "d.M. y G",
	"field-second": "Sekund",
	"field-sat-relative+-1": "lørdag sist uke",
	"field-sun-relative+-1": "søndag sist uke",
	"field-month-relative+0": "denne måneden",
	"field-month-relative+1": "neste måned",
	"dateFormatItem-Ed": "E d.",
	"field-week": "Uke",
	"dateFormat-medium": "d. MMM y G",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "forrige uke",
	"dateFormatItem-yyyyM": "M.y G",
	"field-year-relative+1": "neste år",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "mandag sist uke",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "denne uken",
	"field-week-relative+1": "neste uke"
}
//end v1.x content
);
